@@ -1,4 +1,4 @@
-Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s") {
+Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s", LinLab = NULL) {
   # Rotina para Plotar Graficos do Metodo PCA desenvolvida 
   # por Paulo Cesar Ossani em 11/2014
   
@@ -7,6 +7,8 @@ Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s") {
   # Titles - Titulos para os graficos
   # Color  - "s" para graficos coloridos - default
   #          "n" para graficos em preto e branco
+  # LinLab - Vetor com o rotulo para as linhas, se nao
+  #          informado retorna o padrao dos dados.
   
   # Retorna:
   # Varios graficos
@@ -15,20 +17,26 @@ Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s") {
   # Cria Titulos para os graficos caso nao existam
   if (!is.character(Titles[1]) || is.na(Titles[1])) Titles[1] = c("Grafico Correspondente as Linhas (Observacoes)")
   if (!is.character(Titles[2]) || is.na(Titles[2])) Titles[2] = c("Grafico Correspondente as Colunas (Variaveis)")
-  
+
   Color  = ifelse(Color=="s","S",ifelse(Color=="n","N",Color))    # transforma em maiusculo
-  
+
   if (Color!="S" && Color!="N")
-    return(print("Entrada para 'Color' esta incorreta. Verifique!"))
+     return(print("Entrada para 'Color' esta incorreta. Verifique!"))
+
+  if (!is.null(LinLab) && length(LinLab)!=nrow(PC$MatrixEsc))
+     return(print("O numero elementos do rotulo para linhas (LinLab) difere do numero de linhas da base de dados. Verifique!"))
   
+  if (is.null(LinLab))
+     LinLab <- rownames(PC$MatrixEsc)
+    
   DescEixo1  = paste("Primeira Coordenada Principal (",round(PC$MatrixAutoVlr[1,2],2),"%)",sep="")
   DescEixo2  = paste("Segunda Coordenada Principal (",round(PC$MatrixAutoVlr[2,2],2),"%)",sep="")
   #####   FIM - Informacoes usadas nos Graficos  #####
-  
+
   ##### INICIO - Plotagem dos Autovalores #####
   mp <- barplot(PC$MatrixAutoVlr[,1],names.arg=paste(round(PC$MatrixAutoVlr[,2],2),"%",sep=""),main = "Autovalor")
   ##### FIM - Plotagem dos Autovalores #####
-  
+
   ##### INICIO - Plotagem dos Dados das linhas #####
   plot(PC$MatrixEsc, # cria grafico para as coordenadas principais das linhas
        xlab = DescEixo1,  # Nomeia Eixo X
@@ -40,13 +48,12 @@ Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s") {
        xlim=c(min(PC$MatrixEsc[,1])-0.05,max(PC$MatrixEsc[,1])+0.05), # Dimensao para as linhas do grafico
        ylim=c(min(PC$MatrixEsc[,2])-0.05,max(PC$MatrixEsc[,2])+0.05), # Dimensao para as colunas do grafico
        col = ifelse(Color=="S","red","black"))  # Cor dos pontos
-  
+
   abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
-  
-  LocLab(PC$MatrixEsc[,1:2],rownames(PC$MatrixEsc))  # Coloca os nomes dos pontos das coordenadas principais das linhas
-  #text(PC$MatrixEsc, cex = 1, pos = 3, rownames(PC$MatrixEsc)) # Coloca os nomes dos pontos das coordenadas principais das linhas
+
+  text(PC$MatrixEsc, cex = 1, pos = 3, LinLab)  # Coloca os nomes dos pontos das coordenadas principais das linhas
   ##### FIM - Plotagem dos Dados das linhas #####
-  
+    
   ##### INICIO - Plotagem das Correlacoes dos Componentes Principais com as Variaveis Originais #####
   plot(0,0, # cria grafico para as coordenadas das Correlacoes dos Componentes Principais com as Variaveis Originais
        xlab = DescEixo1, # Nomeia Eixo X
@@ -62,8 +69,7 @@ Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s") {
   abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
   
   arrows(0,0,PC$MatrixCCP[1,],PC$MatrixCCP[2,], lty=1, code = 2, angle = 10, col = ifelse(Color=="S","Blue","Black")) # cria a seta apontando para cada coordenada principal
-
-  LocLab(t(PC$MatrixCCP[1:2,]),colnames(PC$MatrixCCP),col = ifelse(Color=="S","Blue","Black"))  # Coloca os nomes dos pontos das coordenadas principais das linhas
-  #text(t(PC$MatrixCCP), cex=1, colnames(PC$MatrixCCP) , col = ifelse(Color=="S","Blue","Black"), pos = 3, xpd = TRUE)  # Coloca os nomes dos pontos das coordenadas principais
+  
+  text(t(PC$MatrixCCP), cex=1, colnames(PC$MatrixCCP) , col = ifelse(Color=="S","Blue","Black"), pos = 3, xpd = TRUE)  # Coloca os nomes dos pontos das coordenadas principais
   ##### FIM - Plotagem das Correlacoes dos Componentes Principais com as Variaveis Originais #####
-}
+}
\ No newline at end of file
